@@ -247,19 +247,18 @@ class LibraryDatabase(object):
             self.notify('add', book_ids)
         return book_ids[0]
 
-    def find_books_in_directory(self, dirpath, single_book_per_directory):
-        return find_books_in_directory(dirpath, single_book_per_directory)
+    def find_books_in_directory(self, dirpath, single_book_per_directory, compiled_rules=()):
+        return find_books_in_directory(dirpath, single_book_per_directory, compiled_rules=compiled_rules)
 
-    def import_book_directory_multiple(self, dirpath, callback=None,
-            added_ids=None):
-        return import_book_directory_multiple(self, dirpath, callback=callback, added_ids=added_ids)
+    def import_book_directory_multiple(self, dirpath, callback=None, added_ids=None, compiled_rules=()):
+        return import_book_directory_multiple(self, dirpath, callback=callback, added_ids=added_ids, compiled_rules=compiled_rules)
 
-    def import_book_directory(self, dirpath, callback=None, added_ids=None):
-        return import_book_directory(self, dirpath, callback=callback, added_ids=added_ids)
+    def import_book_directory(self, dirpath, callback=None, added_ids=None, compiled_rules=()):
+        return import_book_directory(self, dirpath, callback=callback, added_ids=added_ids, compiled_rules=compiled_rules)
 
-    def recursive_import(self, root, single_book_per_directory=True,
-            callback=None, added_ids=None):
-        return recursive_import(self, root, single_book_per_directory=single_book_per_directory, callback=callback, added_ids=added_ids)
+    def recursive_import(self, root, single_book_per_directory=True, callback=None, added_ids=None, compiled_rules=()):
+        return recursive_import(
+            self, root, single_book_per_directory=single_book_per_directory, callback=callback, added_ids=added_ids, compiled_rules=compiled_rules)
 
     def add_catalog(self, path, title):
         book_id, new_book_added = add_catalog(self.new_api, path, title, dbapi=self)
@@ -276,22 +275,16 @@ class LibraryDatabase(object):
     def add_format(self, index, fmt, stream, index_is_id=False, path=None, notify=True, replace=True, copy_function=None):
         ''' path and copy_function are ignored by the new API '''
         book_id = index if index_is_id else self.id(index)
-        try:
-            return self.new_api.add_format(book_id, fmt, stream, replace=replace, run_hooks=False, dbapi=self)
-        except:
-            raise
-        else:
-            self.notify('metadata', [book_id])
+        ret = self.new_api.add_format(book_id, fmt, stream, replace=replace, run_hooks=False, dbapi=self)
+        self.notify('metadata', [book_id])
+        return ret
 
     def add_format_with_hooks(self, index, fmt, fpath, index_is_id=False, path=None, notify=True, replace=True):
         ''' path is ignored by the new API '''
         book_id = index if index_is_id else self.id(index)
-        try:
-            return self.new_api.add_format(book_id, fmt, fpath, replace=replace, run_hooks=True, dbapi=self)
-        except:
-            raise
-        else:
-            self.notify('metadata', [book_id])
+        ret = self.new_api.add_format(book_id, fmt, fpath, replace=replace, run_hooks=True, dbapi=self)
+        self.notify('metadata', [book_id])
+        return ret
 
     # }}}
 
@@ -910,7 +903,7 @@ LibraryDatabase.metadata_for_field = MT(lambda self, field:self.field_metadata.g
 # }}}
 
 # Miscellaneous API {{{
-for meth in ('get_next_series_num_for', 'has_book', 'author_sort_from_authors'):
+for meth in ('get_next_series_num_for', 'has_book',):
     def getter(meth):
         def func(self, x):
             return getattr(self.new_api, meth)(x)
@@ -924,6 +917,7 @@ LibraryDatabase.saved_search_delete = MT(lambda self, x:self.new_api.saved_searc
 LibraryDatabase.saved_search_add = MT(lambda self, x, y:self.new_api.saved_search_add(x, y))
 LibraryDatabase.saved_search_rename = MT(lambda self, x, y:self.new_api.saved_search_rename(x, y))
 LibraryDatabase.commit_dirty_cache = MT(lambda self: self.new_api.commit_dirty_cache())
+LibraryDatabase.author_sort_from_authors = MT(lambda self, x: self.new_api.author_sort_from_authors(x))
 # Cleaning is not required anymore
 LibraryDatabase.clean = LibraryDatabase.clean_custom = MT(lambda self:None)
 LibraryDatabase.clean_standard_field = MT(lambda self, field, commit=False:None)
