@@ -312,7 +312,7 @@ class SearchRestrictionMixin(object):
     def __init__(self, *args, **kwargs):
         pass
 
-    def init_search_restirction_mixin(self):
+    def init_search_restriction_mixin(self):
         self.checked = QIcon(I('ok.png'))
         self.empty = QIcon(I('blank.png'))
         self.current_search_action = QAction(self.empty, _('*current search'), self)
@@ -589,6 +589,7 @@ class SearchRestrictionMixin(object):
             self._apply_search_restriction(restriction, r)
 
     def clear_additional_restriction(self):
+        self.search_restriction.setCurrentIndex(0)
         self._apply_search_restriction('', '')
 
     def _apply_search_restriction(self, restriction, name):
